==> qtjambi-macextras-5.15.14-sources.jar: io/qt/macextras/QtJambi_LibraryUtilities.java <==
package io.qt.macextras;

import io.qt.*;
import static io.qt.QtUtilities.*;

final class QtJambi_LibraryUtilities {

    final static int qtMajorVersion = 5;

    final static int qtMinorVersion = 15;

    final static int qtJambiPatch = 14;

    final static InternalAccess internal;

    static{
        try {

            QtUtilities.initializePackage("io.qt.widgets");
            initializePackage("io.qt.internal");
            loadQtLibrary("DBus", LibraryRequirementMode.ProvideOnly, "macos", "linux");
            loadQtLibrary("Network", LibraryRequirementMode.ProvideOnly, "linux");
            loadQtLibrary("OpenGL", LibraryRequirementMode.ProvideOnly, "linux");
            loadQtLibrary("PrintSupport", LibraryRequirementMode.ProvideOnly, "macos");
            loadQtLibrary("Qml", LibraryRequirementMode.ProvideOnly);
            loadQtLibrary("QmlModels", LibraryRequirementMode.ProvideOnly);
            loadQtLibrary("Quick", LibraryRequirementMode.ProvideOnly);
            loadQtLibrary("Svg", LibraryRequirementMode.ProvideOnly);
            loadQtLibrary("VirtualKeyboard", LibraryRequirementMode.ProvideOnly);
            loadQtLibrary("WaylandClient", LibraryRequirementMode.ProvideOnly, "linux");
            loadQtLibrary("WaylandEglClientHwIntegration", LibraryRequirementMode.ProvideOnly, "linux");
            loadQtLibrary("Widgets", LibraryRequirementMode.ProvideOnly, "linux", "macos");
            loadQtLibrary("WlShellIntegration", LibraryRequirementMode.ProvideOnly, "linux");
            loadUtilityLibrary("libGLESv2", LibraryRequirementMode.Optional, "windows");
            loadUtilityLibrary("libEGL", LibraryRequirementMode.Optional, "windows");
            loadQtLibrary("Gui", LibraryRequirementMode.Mandatory);
            loadQtLibrary("MacExtras", LibraryRequirementMode.Mandatory);
            loadQtJambiLibrary("MacExtras");
        } catch(Error t) {
            throw t;
        } catch(Throwable t) {
            throw new ExceptionInInitializerError(t);
        }
        internal = internalAccess();
    }
    private static native InternalAccess internalAccess();

    static void initialize() { };

    private QtJambi_LibraryUtilities() throws InstantiationError { throw new InstantiationError("Cannot instantiate QtJambi_LibraryUtilities."); }
}

==> qtjambi-macextras-5.15.19-sources.jar: io/qt/macextras/QtJambi_LibraryUtilities.java <==
package io.qt.macextras;

import io.qt.*;
import static io.qt.QtUtilities.*;

/**
 * @hidden
 */
final class QtJambi_LibraryUtilities {

    final static int qtMajorVersion = 5;

    final static int qtMinorVersion = 15;

    final static int qtJambiPatch = 19;

    final static InternalAccess internal;

    static{
        try {

            QtUtilities.initializePackage("io.qt.widgets");
            initializePackage("io.qt.core");
            loadQtLibrary("DBus", LibraryRequirementMode.ProvideOnly, "macos", "linux");
            loadQtLibrary("EglFSDeviceIntegration", LibraryRequirementMode.ProvideOnly, "linux");
            loadQtLibrary("Network", LibraryRequirementMode.ProvideOnly, "linux");
            loadQtLibrary("OpenGL", LibraryRequirementMode.ProvideOnly, "linux");
            loadQtLibrary("PrintSupport", LibraryRequirementMode.ProvideOnly, "macos");
            loadQtLibrary("Svg", LibraryRequirementMode.ProvideOnly);
            loadQtLibrary("WaylandClient", LibraryRequirementMode.ProvideOnly, "linux");
            loadQtLibrary("Widgets", LibraryRequirementMode.ProvideOnly, "linux", "macos");
            loadQtLibrary("WlShellIntegration", LibraryRequirementMode.ProvideOnly, "linux");
            loadQtLibrary("XcbQpa", LibraryRequirementMode.ProvideOnly, "linux");
            loadUtilityLibrary("libGLESv2", LibraryRequirementMode.Optional, "windows");
            loadUtilityLibrary("libEGL", LibraryRequirementMode.Optional, "windows");
            loadQtLibrary("Gui", LibraryRequirementMode.Mandatory);
            loadQtLibrary("MacExtras", LibraryRequirementMode.Mandatory);
            loadQtJambiLibrary("MacExtras");
        } catch(Error t) {
            throw t;
        } catch(Throwable t) {
            throw new ExceptionInInitializerError(t);
        }
        internal = internalAccess();
    }
    private static native InternalAccess internalAccess();

    static void initialize() { };

    private QtJambi_LibraryUtilities() throws InstantiationError { throw new InstantiationError("Cannot instantiate QtJambi_LibraryUtilities."); }
}
